@@ -1,7 +1,7 @@
 /**
  * @file callbacks.h misc UI stuff
  *
- * Copyright (C) 2003, 2004 Lars Lindner <lars.lindner@gmx.net>
+ * Copyright (C) 2003-2006 Lars Lindner <lars.lindner@gmx.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,40 +22,23 @@
 #define _CALLBACKS_H
 
 #include <gtk/gtk.h>
-#include "ui_mainwindow.h"
-#include "ui_feedlist.h"
-#include "ui_itemlist.h"
-#include "ui_folder.h"
-#include "ui_search.h"
-#include "ui_popup.h"
-#include "ui_prefs.h"
-#include "ui_dnd.h"
+#include "ui/ui_mainwindow.h"
+#include "ui/ui_feedlist.h"
+#include "ui/ui_itemlist.h"
+#include "ui/ui_node.h"
+#include "ui/ui_folder.h"
+#include "ui/ui_search.h"
+#include "ui/ui_popup.h"
+#include "ui/ui_prefs.h"
+#include "ui/ui_dnd.h"
+#include "ui/ui_htmlview.h"
+#include "ui/ui_tabs.h"
+#include "ui/ui_update.h"
+#include "scripting/ui_script.h"
 #include "export.h"
-#include "ui_htmlview.h"
-#include "ui_tabs.h"
 #include "itemlist.h"
 #include "feedlist.h"
-
-/* icon constants */
-enum icons {
-	ICON_READ,
-	ICON_UNREAD,
-	ICON_FLAG,
-	ICON_AVAILABLE,
-	ICON_AVAILABLE_OFFLINE,
-	ICON_UNAVAILABLE,
-	ICON_OCS,
-	ICON_FOLDER,
-	ICON_VFOLDER,
-	ICON_EMPTY,
-	ICON_EMPTY_OFFLINE,
-	ICON_ONLINE,
-	ICON_OFFLINE,
-	ICON_UPDATED,
-	MAX_ICONS
-};
-
-extern GdkPixbuf *icons[MAX_ICONS];
+#include "newsbin.h"
 
 /** 
  * GUI initialization methods. Sets up dynamically created
@@ -63,11 +46,6 @@ extern GdkPixbuf *icons[MAX_ICONS];
  */
 void ui_init(gint mainwindowState);
 
-#define ui_redraw_itemlist()	ui_redraw_widget("Itemlist");
-#define ui_redraw_feedlist()	ui_redraw_widget("feedlist");
-
-void ui_redraw_widget(gchar *name);
-
 void ui_show_info_box(const char *format, ...);
 void ui_show_error_box(const char *format, ...);
 
@@ -99,16 +77,6 @@ void
 on_about_activate                      (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
-gboolean
-on_close                               (GtkWidget       *widget,
-                                        GdkEvent        *event,
-                                        gpointer         user_data);
-
-gboolean
-on_mainwindow_window_state_event       (GtkWidget       *widget,
-                                        GdkEvent        *event,
-                                        gpointer         user_data);
-
 void
 on_homepagebtn_clicked                 (GtkButton       *button,
                                         gpointer         user_data);
@@ -125,4 +93,3 @@ void
 on_faq_activate                        (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 #endif
-
