@@ -32,13 +32,18 @@
 #include <errno.h>
 #include <glib.h>
 #include <gtkmozembed.h>
-#include "ui_htmlview.h"
+#include "mozilla/mozsupport.h"
+#include "common.h"
 #include "conf.h"
 #include "support.h"
 #include "debug.h"
-#include "ui_popup.h"
-#include "ui_tabs.h"
-#include "mozsupport.h"
+#include "ui/ui_htmlview.h"
+#include "ui/ui_popup.h"
+#include "ui/ui_tabs.h"
+
+#define EMPTY "<html><body></body></html>"
+
+extern GtkWidget *mainwindow;
 
 /* points to the URL actually under the mouse pointer or is NULL */
 static gchar		*selectedURL = NULL;
@@ -52,10 +57,17 @@ void mozembed_write(GtkWidget *widget, const gchar *string, guint length, const
 	
 	if(!GTK_WIDGET_REALIZED(widget)) 
 		return;
-		
+
 	/* prevent meta refresh of last document */
 	gtk_moz_embed_stop_load(GTK_MOZ_EMBED(widget));
 	
+	/* always prevent following local links in self-generated HTML */
+	g_object_set_data(G_OBJECT(widget), "localDocument", GINT_TO_POINTER(FALSE));
+	
+	if(DEBUG_VERBOSE & debug_level)
+		debug1(DEBUG_HTML, "mozilla: HTML string >>>%s<<<", string);
+	debug0(DEBUG_HTML, "mozilla: start writing...");
+	
 	if((NULL != string) && (length > 0)) {
 		/* Because of a bug in Mozilla, sending the entire string at
 		   once causes Mozilla to hang. This seems to avoid that
@@ -67,15 +79,21 @@ void mozembed_write(GtkWidget *widget, const gchar *string, guint length, const
 		gtk_moz_embed_open_stream(GTK_MOZ_EMBED(widget), "file://", (contentType != NULL) ? contentType : "text/html");
 		while (left > 0) {
 			if (left > 4096) {
+				debug1(DEBUG_HTML, "mozilla: appending 4 kbytes (missing %d)", left-4096);
 				gtk_moz_embed_append_data(GTK_MOZ_EMBED(widget), string, 4096);
 				string += 4096;
-			} else
+			} else {
+				debug1(DEBUG_HTML, "mozilla: appending remaining %d bytes", left);
 				gtk_moz_embed_append_data(GTK_MOZ_EMBED(widget), string, left);
+			}
 			left -=4096;
 		}
 		gtk_moz_embed_close_stream(GTK_MOZ_EMBED(widget));
-	} else
+	} else {
 		gtk_moz_embed_render_data(GTK_MOZ_EMBED(widget), EMPTY, strlen(EMPTY), base, "text/html");
+	}
+	
+	debug0(DEBUG_HTML, "mozilla: writing finished.");
 		
 	mozsupport_scroll_to_top(widget);
 }
@@ -137,7 +155,7 @@ static void mozembed_link_message_cb(GtkMozEmbed *dummy, gpointer embed) {
 	g_free(selectedURL);
 	if(NULL != (selectedURL = gtk_moz_embed_get_link_message(dummy))) {
 		/* overwrite or clear last status line text */
-		ui_mainwindow_set_status_bar("%s", g_strdup(selectedURL));
+		ui_htmlview_on_url(selectedURL);
 		
 		/* mozilla gives us an empty string when no link is selected */
 		if(0 == strlen(selectedURL)) {
@@ -156,33 +174,47 @@ static gint mozembed_dom_key_press_cb (GtkMozEmbed *dummy, gpointer dom_event, g
  * clicks on the document
  */
 static gint mozembed_dom_mouse_click_cb (GtkMozEmbed *dummy, gpointer dom_event, gpointer embed) {
-	gint	button;
+	gint		button;
+	gboolean	isLocalDoc, safeURL = FALSE;
 
 	if(-1 == (button = mozsupport_get_mouse_event_button(dom_event))) {
 		g_warning("Cannot determine mouse button!\n");
 		return FALSE;
 	}
-	
+
+	/* source document in local filesystem? */
+	isLocalDoc = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(GTK_WIDGET(dummy)), "localDocument"));
+
+	/* prevent launching local filesystem links */	
+	if(selectedURL)
+		safeURL = (NULL == strstr(selectedURL, "file://")) || isLocalDoc;
+
 	/* do we have a right mouse button click? */
 	if(button == 2) {
-		if(NULL == selectedURL)
+		if(!selectedURL)
 			gtk_menu_popup(GTK_MENU(make_html_menu()), NULL, NULL,
 				       NULL, NULL, button, 0);
 		else
-			gtk_menu_popup(GTK_MENU(make_url_menu(selectedURL)), NULL, NULL,
+			gtk_menu_popup(GTK_MENU(make_url_menu(safeURL?selectedURL:"")), NULL, NULL,
 				       NULL, NULL, button, 0);
 	
 		return TRUE;
-	/* or a middle button click */
-	} else if(button == 1) {
-		if(NULL != selectedURL) {	
+	} else {
+		if(!selectedURL)
+			return FALSE;	/* should never happen */
+			
+		if(!safeURL)
+			return TRUE;
+			
+		/* on middle button click */
+		if(button == 1) {
 			ui_tabs_new(selectedURL, selectedURL, FALSE);
 			return TRUE;
+	
+		/* on left button click */
 		} else {
 			return FALSE;
-		}			
-	} else {
-		return FALSE;
+		}
 	}
 }
 
@@ -196,8 +228,8 @@ static gint mozembed_dom_mouse_click_cb (GtkMozEmbed *dummy, gpointer dom_event,
 static gint mozembed_open_uri_cb (GtkMozEmbed *embed, const char *uri, gpointer data) {
 	
 	if((FALSE == ui_htmlview_is_special_url(uri)) && 
-	   (GPOINTER_TO_INT(g_object_get_data(G_OBJECT(embed), "internal_browsing")) || 
-	    getBooleanConfValue(BROWSE_INSIDE_APPLICATION))) {
+	   (GPOINTER_TO_INT(g_object_get_data(G_OBJECT(embed), "internal_browsing")) ||
+	   getBooleanConfValue(BROWSE_INSIDE_APPLICATION))) {
 		return FALSE;
 	} else {
 		ui_htmlview_launch_URL(GTK_WIDGET(data), (gchar *)uri, UI_HTMLVIEW_LAUNCH_DEFAULT);
@@ -209,6 +241,7 @@ static gint mozembed_open_uri_cb (GtkMozEmbed *embed, const char *uri, gpointer
    The signal setting was derived from the Galeon source. */
 GtkWidget * mozembed_create(gboolean forceInternalBrowsing) {
 	GtkWidget	*widget;
+	gchar		*bgColor;
 	int		i;
 	
 	/* signals to connect on each embed widget */
@@ -255,6 +288,15 @@ GtkWidget * mozembed_create(gboolean forceInternalBrowsing) {
 	
 	g_object_set_data(G_OBJECT(widget), "internal_browsing", GINT_TO_POINTER(forceInternalBrowsing));
 	
+	/* enforce GTK theme background color as document background */	
+	bgColor = g_strdup_printf("#%.2x%.2x%.2x",
+	                          mainwindow->style->base[GTK_STATE_NORMAL].red >> 8,
+	                          mainwindow->style->base[GTK_STATE_NORMAL].green >> 8,
+	                          mainwindow->style->base[GTK_STATE_NORMAL].blue >> 8);
+
+	mozsupport_preference_set("browser.display.background_color", bgColor);
+	g_free(bgColor);
+	
 	return widget;
 }
 
@@ -267,7 +309,7 @@ void mozembed_init(void) {
 	g_assert(g_thread_supported());
 	
 	/* set a path for the profile */
-	profile = g_build_filename(g_get_home_dir(), ".liferea/mozilla", NULL);
+	profile = g_build_filename(common_get_cache_path(), "mozilla", NULL);
 
 	/* initialize profile */
 	gtk_moz_embed_set_profile_path(profile, "liferea");
@@ -297,6 +339,11 @@ void mozembed_deinit(void) {
 
 /* launches the specified URL */
 void mozembed_launch_url(GtkWidget *widget, const gchar *url) {
+	gboolean isLocalDoc;
+
+	/* determine if launched URL is a local one and set the flag to allow following local links */
+	isLocalDoc = (url == strstr(url, "file://"));
+	g_object_set_data(G_OBJECT(widget), "localDocument", GINT_TO_POINTER(isLocalDoc));
 
 	gtk_moz_embed_load_url(GTK_MOZ_EMBED(widget), url); 
 }
