@@ -1,7 +1,7 @@
 /**
  * @file vfolder.h VFolder functionality
  *
- * Copyright (C) 2003, 2004 Lars Lindner <lars.lindner@gmx.net>
+ * Copyright (C) 2003-2006 Lars Lindner <lars.lindner@gmx.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,15 +21,42 @@
 #ifndef _VFOLDER_H
 #define _VFOLDER_H
 
-#include "feed.h"
+#include <glib.h>
 #include "item.h"
 #include "rule.h"
 
-/* standard feed/item type interface */
-feedHandlerPtr	vfolder_init_feed_handler(void);
+/* The vfolder implementation of Liferea is similar to the
+   one in Evolution. Vfolders are effectivly permanent searches.
 
-/* sets up a vfolder feed structure */
-feedPtr vfolder_new(void);
+   Each vfolder instance is a set of rules applied to all items
+   of all other feeds (excluding other vfolders). Each vfolder
+   instance can have a single node in the feed list. 
+   
+   The vfolder concept also constitutes an own itemset type
+   with special update propagation and removal handling. */
+
+typedef struct vfolder {
+	GSList		*rules;			/**< list of rules if this is a vfolder */
+	struct node	*node;			/**< the node of the vfolder, needed for merging */
+} *vfolderPtr;
+
+/**
+ * Initialize vfolder handling.
+ */
+void	vfolder_init(void);
+
+/**
+ * Sets up a new vfolder structure.
+ *
+ * @param node 	the feed list node of the vfolder
+ *
+ * @returns a new vfolder
+ */
+vfolderPtr vfolder_new(struct node *node);
+
+/* set/get of vfolder title */
+const gchar * vfolder_get_title(vfolderPtr vp);
+void vfolder_set_title(vfolderPtr vp, const gchar * title);
 
 /**
  * Method thats adds a rule to a vfolder. To be used
@@ -41,7 +68,7 @@ feedPtr vfolder_new(void);
  * @param value		argument string for this rule
  * @param additive	indicates positive or negative logic
  */
-void	vfolder_add_rule(feedPtr vp, const gchar *ruleId, const gchar *value, gboolean additive);
+void	vfolder_add_rule(vfolderPtr vp, const gchar *ruleId, const gchar *value, gboolean additive);
 
 /** 
  * Method that removes a rule from a vfolder. To be used
@@ -51,7 +78,7 @@ void	vfolder_add_rule(feedPtr vp, const gchar *ruleId, const gchar *value, gbool
  * @param vp	vfolder
  * @param rp	rule to remove
  */
-void	vfolder_remove_rule(feedPtr vp, rulePtr rp);
+void	vfolder_remove_rule(vfolderPtr vp, rulePtr rp);
 
 /**
  * Method that applies the rules of the given vfolder to 
@@ -61,7 +88,7 @@ void	vfolder_remove_rule(feedPtr vp, rulePtr rp);
  *
  * @param vp	vfolder
  */
-void	vfolder_refresh(feedPtr vp);
+void	vfolder_refresh(vfolderPtr vp);
 
 /**
  * Method to be called when a item was updated. This maybe
@@ -80,10 +107,18 @@ void	vfolder_update_item(itemPtr ip);
  * copy again. This may remove the item copy if it does not
  * longer match the vfolder rules.
  *
- * @param ip	item of a feed to check
+ * @param item	node item to check
  * @returns TRUE if item (still) added, FALSE otherwise
  */
-gboolean vfolder_check_item(itemPtr ip);
+gboolean vfolder_check_item(itemPtr item);
+
+/**
+ * Method to be called during initial node loading to check
+ * all items of a single node for vfolder rule macthing.
+ *
+ * @param node	the node whose items are to be checked
+ */
+void vfolder_check_node(struct node *node);
 
 /** 
  * Searches all vfolders for copies of the given item and
@@ -100,6 +135,9 @@ void	vfolder_remove_item(itemPtr ip);
  *
  * @param vp	vfolder to free
  */
-void	vfolder_free(feedPtr vp);
+void	vfolder_free(vfolderPtr vp);
+
+/* implementation of the node type interface */
+struct nodeType * vfolder_get_node_type(void);
 
 #endif
